@@ -6,7 +6,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  AIC model test   R O U T I N E S
  
  Peter Beerli 2001, Seattle
- beerli@gs.washington.edu
+ beerli@csit.fsu.edu
  
  Copyright 2001-2002 Peter Beerli and Joseph Felsenstein
  
@@ -14,7 +14,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: aic.c,v 1.19 2003/05/31 15:10:15 beerli Exp $ 
+$Id: aic.c,v 1.20 2003/11/04 16:12:07 beerli Exp $ 
 -------------------------------------------------------*/
 #include "migration.h"
 #include "tools.h"
