@@ -10,7 +10,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  
  
  Peter Beerli 1997, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
  Copyright 2001 Peter Beerli and Joseph Felsenstein
  
@@ -18,7 +18,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
- $Id: broyden.c,v 1.68 2003/06/10 15:55:19 beerli Exp $
+ $Id: broyden.c,v 1.71 2003/11/04 16:12:08 beerli Exp $
 -------------------------------------------------------*/
 extern double norm (double *d, long size);
 
@@ -55,7 +55,7 @@ double probG2 (double *param, double *lparam, double *sm, double *kt,
                long numpop);
 void probG3 (double *apg, double *apg0r, timearchive_fmt * tyme, long numpop,
              double *apgmax, double *param, double *lparam, double *sm);
- double probG4 (double *fullparam, double *data, long numpop, long numpop2);
+inline  double probG4 (double *fullparam, double *data, long numpop, long numpop2);
 double logprob_noevent (world_fmt * world, long interval);
 double sum_migprob (world_fmt * world, long pop, long interval);
 double sum_mig (double *param, long msta, long msto);
@@ -182,7 +182,7 @@ calc_line_new (helper_fmt * helper, double a, double b, double c,
     int panic = 0;
     low = (*fpsi) (xlow, helper);
     high = (*fpsi) (xhigh, helper);
-    xmid = (xlow + xhigh) / 2.;
+    xmid = (xlow + xhigh) * HALF;
     while (panic++ < 10000 && fabs (xhigh - xlow) > EPSILON)
     {
         mid = (*fpsi) (xmid, helper);
@@ -212,17 +212,12 @@ quadratic_constants (double *xguess,
     double xhigh2 = xhigh * xhigh;
     double xlow2 = xlow * xlow;
     double xmid2 = xmid * xmid;
-
+    double divisor =        ((xlow - xmid) * (xlow * xmid - xlow * xhigh - xmid * xhigh + xhigh2));
     double a = -((-(xmid * low) + xhigh * low + xlow * mid - xhigh * mid -
-                  xlow * high + xmid * high) /
-                 ((xlow - xmid) * (xlow * xmid - xlow * xhigh - xmid * xhigh +
-                                   xhigh2)));
+                  xlow * high + xmid * high) /divisor);
     double b =
         -((xmid2 * low - xhigh2 * low - xlow2 * mid + xhigh2 * mid +
-           xlow2 * high - xmid2 * high) / ((xlow - xmid) * (xlow * xmid -
-                                           xlow * xhigh -
-                                           xmid * xhigh +
-                                           xhigh2)));
+           xlow2 * high - xmid2 * high) / divisor);
     //    double c = -((-(xmid2*xhigh*low) + xmid*xhigh2*low +
     //    xlow2*xhigh*mid - xlow*xhigh2*mid -
     //    xlow2*xmid*high + xlow*xmid2*high)/
@@ -728,7 +723,7 @@ calc_locus_like (nr_fmt * nr, double *param, double *lparam, long locus)
     FloatVec *vlocal;
     // FloatVec *vdata;
     size4 -= (size4 % 4) - 4;
-    size = size4 / 4;
+    size = size4 * QUARTER;
     vlocal = (FloatVec *) calloc (MAX(16,size), sizeof(FloatVec));
     // vdata = (FloatVec *) calloc (MAX(16,size), sizeof(FloatVec));
     locallparam = (double *) calloc ((size4), sizeof (double));
@@ -996,7 +991,7 @@ param_all_adjust (double *xv, nr_fmt *nr)
                     }
                     else
                     {
-                        mm = (EXP (param[syms[i][0]]) + EXP (param[syms[i][1]])) / 2.;
+                        mm = (EXP (param[syms[i][0]]) + EXP (param[syms[i][1]]))  * HALF;
                         param[syms[i][0]] = param[syms[i][1]] = log (mm);
                         break;
                     }
@@ -1005,7 +1000,7 @@ param_all_adjust (double *xv, nr_fmt *nr)
         }
         else
         {
-            mm = (EXP (param[syms[i][0]]) + EXP (param[syms[i][1]])) / 2.;
+            mm = (EXP (param[syms[i][0]]) + EXP (param[syms[i][1]])) * HALF;
             param[syms[i][0]] = param[syms[i][1]] = log (mm);
         }
     }
@@ -1036,7 +1031,7 @@ param_all_adjust (double *xv, nr_fmt *nr)
                     else
                     {
                         mm = (EXP (param[sym2s[i][0]] + param[sym2s[i][2]]) +
-                              EXP (param[sym2s[i][1]] + param[sym2s[i][3]])) / 2.;
+                              EXP (param[sym2s[i][1]] + param[sym2s[i][3]])) * HALF;
                         param[sym2s[i][0]] = (lmm = log (mm)) - param[sym2s[i][2]];
                         param[sym2s[i][1]] = lmm - param[sym2s[i][3]];
                         break;
@@ -1047,7 +1042,7 @@ param_all_adjust (double *xv, nr_fmt *nr)
         else
         {
             mm = (EXP (param[sym2s[i][0]] + param[sym2s[i][2]]) +
-                  EXP (param[sym2s[i][1]] + param[sym2s[i][3]])) / 2.;
+                  EXP (param[sym2s[i][1]] + param[sym2s[i][3]])) * HALF;
             param[sym2s[i][0]] = (lmm = log (mm)) - param[sym2s[i][2]];
             param[sym2s[i][1]] = lmm - param[sym2s[i][3]];
         }
@@ -1160,7 +1155,7 @@ check_matrix_arbitrary (double *param, worldoption_fmt * wopt, long numpop, long
                 param[syms[i][0]] = param[syms[i][1]];
             else
             {
-                mm = (EXP (param[syms[i][0]]) + EXP (param[syms[i][1]])) / 2.;
+                mm = (EXP (param[syms[i][0]]) + EXP (param[syms[i][1]])) * HALF;
                 param[syms[i][0]] = param[syms[i][1]] = log (mm);
             }
         }
@@ -1176,7 +1171,7 @@ check_matrix_arbitrary (double *param, worldoption_fmt * wopt, long numpop, long
             else
             {
                 mm = (EXP (param[sym2s[i][0]] + param[sym2s[i][2]]) +
-                      EXP (param[sym2s[i][1]] + param[sym2s[i][3]])) / 2.;
+                      EXP (param[sym2s[i][1]] + param[sym2s[i][3]])) * HALF;
             }
         }
         param[sym2s[i][0]] = (lmm = log (mm)) - param[sym2s[i][2]];
@@ -1199,8 +1194,10 @@ gradient (double *d, nr_fmt * nr, long locus)
     double *geo = nr->world->data->geo;
     tarchive_fmt *tl;
     double tet;
+    double rtet;
     double *normalgrad;
     double mu_rate = nr->world->options->mu_rates[locus];
+    double inv_mu_rate = 1. / mu_rate;
     normalgrad = malloc(nr->numpop2 * sizeof(double));
     memset (d, 0, sizeof (double) * nr->numpop2);
     thetas = nr->param;
@@ -1220,7 +1217,10 @@ gradient (double *d, nr_fmt * nr, long locus)
             for (pop = 0; pop < numpop; pop++)
             {
                 tet = thetas[pop];
-                nr->parts[pop] = -tl[g].p[pop] / tet + tl[g].kt[pop] / (tet * tet * mu_rate) - normalgrad[pop];
+                // the following lines are doing this derivative, but have reduced the division operation (speed)
+                // nr->parts[pop] = -tl[g].p[pop] / tet + tl[g].kt[pop] / (tet * tet * mu_rate) - normalgrad[pop];
+                rtet = 1./(tet * tet * mu_rate);
+                nr->parts[pop] = (- mu_rate * tet * (tl[g].p[pop] + normalgrad[pop] * tet)  + tl[g].kt[pop]) * rtet ;
                 msta = nr->mstart[pop];
                 msto = nr->mend[pop];
                 z = 0;
@@ -1231,23 +1231,24 @@ gradient (double *d, nr_fmt * nr, long locus)
                     {
                         if(nr->world->options->custm2[i]=='S')
                         {
-                            found =find (i, nr->profiles, nr->profilenum);
-                            if (!found)
-                                nr->parts[i] = ((tl[g].mindex[i] / (nr->param[i]))
-                                                - geo[i] * tl[g].km[pop] / mu_rate) - normalgrad[i];
-
-                            symmetric_other(i, numpop, &other, &otherpop);
-                            tk1 = geo[i]* tl[g].km[pop] / mu_rate;
+                            tk1 = geo[i]* tl[g].km[pop] * inv_mu_rate;
                             l1 = tl[g].mindex[i];
                             m1 = nr->param[i];
                             th1 = nr->param[pop];
+                            found =find (i, nr->profiles, nr->profilenum);
+                            if (!found)
+                            {
+                                nr->parts[i] = ((l1 / m1) - tk1) - normalgrad[i];
+                            }
+                            symmetric_other(i, numpop, &other, &otherpop);
                             th2 = nr->param[otherpop];
                             nm1 = m1 * th1;
-                            nr->parts[pop]  += tk1 * m1/th1 - l1/th1;
+                            // speed opt: nr->parts[pop]  += tk1 * m1/th1 - l1/th1;
+                            nr->parts[pop]  += tk1 * (m1 - l1)/th1;
                         }
                         else
                             nr->parts[i] = ((tl[g].mindex[i] / (nr->param[i]))
-                                            - geo[i] * tl[g].km[pop] / mu_rate) - normalgrad[i];
+                                            - geo[i] * tl[g].km[pop] * inv_mu_rate) - normalgrad[i];
                     }
                 }
             }
@@ -1682,7 +1683,7 @@ grad2loggrad (double *param, long *indeks, double *d, long nn,
     }
 }
 
-double
+inline double
 probG (double *param, double *lparam, tarchive_fmt * tl, nr_fmt * nr,
        long locus)
 {
@@ -1714,7 +1715,7 @@ probG (double *param, double *lparam, tarchive_fmt * tl, nr_fmt * nr,
     return result;
 }
 
- double
+inline  double
 probG4 (double *fullparam, double *data, long numpop, long numpop2)
 {
     int i;
