@@ -10,11 +10,11 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: combroyden.h,v 1.23 2002/06/20 06:25:33 beerli Exp $
+$Id: combroyden.h,v 1.24 2003/11/04 16:12:08 beerli Exp $
  
 -------------------------------------------------------*/
 
