@@ -12,7 +12,7 @@
  destroys data.
  
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
@@ -21,7 +21,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c,v 1.45 2003/03/13 20:15:31 beerli Exp $
+$Id: data.c,v 1.47 2003/11/04 16:12:08 beerli Exp $
  
 -------------------------------------------------------*/
 #include <string.h>
@@ -137,13 +137,13 @@ get_data (FILE * infile, data_fmt * data, option_fmt * options)
         fprintf (options->logfile, "\n\n");
     for (pop = 0; pop < data->numpop; pop++)
     {
-        read_popheader (data->infile, data, pop, genomes);
+        read_popheader (infile, data, pop, genomes);
         if (options->progress)
             fprintf (stdout, "Reading %s ...\n", data->popnames[pop]);
         if (options->writelog)
             fprintf (options->logfile, "Reading %s ...\n", data->popnames[pop]);
         init_data_structure2 (&data, options, pop);
-        read_popdata (data->infile, data, pop, options);
+        read_popdata (infile, data, pop, options);
     }
     read_geofile (data, options, data->numpop);
 #ifdef UEP
@@ -387,6 +387,7 @@ find_delimiter (char *title, char *dlm)
 }
 
 
+/*  old sites reader, will be obsolete once the new is working correctly
 void
 read_sites (data_fmt * data)
 {
@@ -417,11 +418,44 @@ read_sites (data_fmt * data)
     free (input);
 
 }
+*/
 
+//==================================================================
+// read the number of sites for each locus in the dataset
+// does not assume a fixed line length, but assumes that at the end of the line is either
+// a \n or \r or \r\l (similar to the sequence reader) to accommodate windows, mac and
+// unix line ends
+void
+read_sites (data_fmt * data)
+{
+    long locus;
+    char *input;
+    input = calloc(LINESIZE,sizeof(char));
+    
+    for (locus = 0; locus < data->loci-1; locus++)
+    {
+        read_word(data->infile, input);
+        data->seq->sites[locus] = atoi (input);
+        if (data->seq->sites[locus] == 0)
+        {
+            warning ("This does look like sequence data\n");
+            warning ("I just read a number of sites=0\n");
+            warning ("If you use the wrong data type, the program\n");
+            usererror ("will crash anyway, so I stop now\n");
+        }
+    }
+        FGETS(input,LINESIZE,data->infile);
+        data->seq->sites[locus] = atoi (input);
+
+    free (input);
+
+}
+
+/*
 void
 read_popheader (FILE * infile, data_fmt * data, long pop, long genomes)
 {
-    char input[LINESIZE], *p, *tmp;
+    char input[SUPERLINESIZE], *p, *tmp;
     long locus,lo;
     boolean havepopname=FALSE;
     FGETS (input, sizeof (input), infile);
@@ -495,6 +529,75 @@ read_popheader (FILE * infile, data_fmt * data, long pop, long genomes)
     //    data->hasghost = TRUE;
     //#endif
 }
+*/
+
+void
+read_popheader (FILE * infile, data_fmt * data, long pop, long genomes)
+{
+    long lo;
+    boolean havepopname=FALSE;
+    long locus;
+    char *input;
+    input = (char *) calloc(LINESIZE,sizeof(char));
+#ifdef NEWSTYLE
+    // allows that sequence data can have different numbers of individuals for different loci
+    // data syntax changes: #ind1 #ind2 #IND3 .... pop_name
+    havepopname=FALSE;
+    if(data->loci>1)
+    {
+        read_word(data->infile, input);
+        data->numind[pop][0] = atol(input);
+        data->numalleles[pop][0] = data->numind[pop][0] * genomes;
+        for(locus=1; locus< data->loci; locus++)
+        {
+            read_word(infile, input);
+            if(isdigit(input[0]))
+            {
+                data->numind[pop][locus] = atol(input);
+                data->numalleles[pop][locus] = data->numind[pop][locus]*genomes;
+            }
+            else
+            {
+                unread_word(infile, input);
+                FGETS(input,LINESIZE,infile);
+                havepopname=TRUE;
+                strncpy(data->popnames[pop],input,MIN(strlen(input),80));
+                break;
+            }
+        }
+        if(!havepopname)
+        {
+            read_word(infile, input);
+            strncpy(data->popnames[pop],input,MIN(strlen(input),80));
+        }
+
+        // fills numind for additional locus in case the numind was not specified
+        for(lo=locus; lo< data->loci; lo++)
+        {
+            data->numind[pop][lo] = data->numind[pop][locus-1];
+            data->numalleles[pop][lo] = data->numind[pop][lo] * genomes;
+        }
+    }
+    else
+    {
+        // only one locus so we can use old scheme [see below]
+        FGETS(input,LINESIZE,infile);
+        sscanf (input, "%ld%[^\n]", &(data->numind[pop][0]),
+                data->popnames[pop]);
+        data->numalleles[pop][0] = data->numind[pop][0]*genomes;
+    }
+#else
+    // assume all loci have the same number of individuals
+    FGETS(input,LINESIZE,infile);
+    sscanf (input, "%ld%[^\n]", &(data->numind[pop][0]),
+            data->popnames[pop]);
+    data->numalleles[pop][0] = data->numind[pop][0]*genomes;
+#endif
+
+    translate (data->popnames[pop], ' ', '_');
+    translate (data->popnames[pop], '\t', '_');
+}
+
 
 void
 read_indname (FILE * file, data_fmt * data, long pop, long ind, long nmlength)
@@ -555,14 +658,14 @@ read_microalleles (FILE * infile, data_fmt * data, long pop, long ind)
 {
     char *input, *isave, dlm[2], ddlm[2], *p, *a, *a1, *a2;
     long locus, i;
-    input = (char *) calloc (1, sizeof (char) * (LONGLINESIZE + 1));
+    input = (char *) calloc (1, sizeof (char) * (SUPERLINESIZE + 1));
     isave = input;
     a = (char *) calloc (1, sizeof (char) * LINESIZE);
     a1 = (char *) calloc (1, sizeof (char) * LINESIZE);
     a2 = (char *) calloc (1, sizeof (char) * LINESIZE);
     dlm[0] = data->dlm, dlm[1] = '\0';
     ddlm[0] = ' ', ddlm[1] = '\0';
-    FGETS (input, LONGLINESIZE, infile);
+    FGETS (input, SUPERLINESIZE, infile);
     if ((p = (char *) strpbrk (input, CRLF)) != NULL)
         *p = '\0';
     for (locus = 0; locus < data->loci; locus++)
@@ -570,7 +673,7 @@ read_microalleles (FILE * infile, data_fmt * data, long pop, long ind)
         while (isspace ((int) *input))
             input++;
         if (input[0] == '\0')
-            FGETS (input, LONGLINESIZE, infile);
+            FGETS (input, SUPERLINESIZE, infile);
         i = 0;
         while (strchr(" \t",input[i])==NULL && input[i] != dlm[0])
         {
@@ -615,9 +718,9 @@ read_alleles (FILE * infile, data_fmt * data, long pop, long ind)
     long locus;
     a = (char *) calloc (1, sizeof (char) * LINESIZE);
 
-    input = (char *) calloc (1, sizeof (char) * LONGLINESIZE);
+    input = (char *) calloc (1, sizeof (char) * SUPERLINESIZE);
     isave = input;
-    FGETS (input, LONGLINESIZE, infile);
+    FGETS (input, SUPERLINESIZE, infile);
     if ((p = (char *) strpbrk (input, CRLF)) != NULL)
         *p = '\0';
     for (locus = 0; locus < data->loci; locus++)
@@ -708,14 +811,14 @@ read_ind_seq (FILE * infile, data_fmt * data, option_fmt * options,
 void
 read_distance_fromfile (FILE * dfile, long tips, long nmlength, double **m)
 {
-    char input[LINESIZE];
+    char input[SUPERLINESIZE];
     long i, j;
 
     if (dfile != NULL)
     {
         // assumes that the dfile is in PHYLIP format
         // and that all n x n cells are filled.
-        FGETS (input, LINESIZE, dfile); //reads header line with
+        FGETS (input, LONGLINESIZE, dfile); //reads header line with
         for (i = 0; i < tips; i++) // of individuals
         {
             //reads header line with
@@ -726,7 +829,7 @@ read_distance_fromfile (FILE * dfile, long tips, long nmlength, double **m)
             }
             // reads the last \n from the
             // data matrix
-            FGETS (input, LINESIZE, dfile);
+            FGETS (input, LONGLINESIZE, dfile);
         }
     }
 }
