@@ -18,11 +18,11 @@
  M(1) = m(1)/mu, and M(2)= m(2)/mu
                                                                                                                
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: data.h,v 1.13 2002/06/20 06:25:34 beerli Exp $
+$Id: data.h,v 1.14 2003/11/04 16:12:08 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
