@@ -9,7 +9,7 @@
   Genetics 357360
   University of Washington
   Seattle, WA 98195-7360, USA
-  beerli@genetics.washington.edu
+  beerli@csit.fsu.edu
  
   With help of Joe Felsenstein (joe@genetics.washington.edu),
   Mary Kuhner and Jon Yamato (mkkuhner@genetics.washington.edu)
@@ -17,20 +17,20 @@
   
 Copyright 2002 Peter Beerli and Joseph Felsenstein
  
-$Id: definitions.h,v 1.81 2003/06/10 15:55:19 beerli Exp $
+$Id: definitions.h,v 1.85 2003/11/19 03:52:37 beerli Exp $
  
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "1.7.3"
+#define MIGRATEVERSION "1.7.6"
 #else
 #ifdef SGI
 #undef MIGRATEVERSION
-#define MIGRATEVERSION "1.7.3"
+#define MIGRATEVERSION "1.7.6"
 #endif
 #endif
 
-#define MAINTAINER "Peter Beerli <beerli@gs.washington.edu>"
+#define MAINTAINER "Peter Beerli <beerli@csit.fsu.edu>"
 /*------------------------------------------------
   Adjusting the source to the system configuration
 */
@@ -224,9 +224,9 @@ typedef unsigned char boolean;
 #define MAXALLELES            93
 #define SMALLBUFSIZE    255
 #define MAXBUFSIZE        100000
-/* #define LINESIZE            1024*/ /* setting this smaller can break */
-#define LINESIZE           10000 
+#define LINESIZE            10000 /* setting this smaller can break */
 #define LONGLINESIZE       10000 /* setting this smaller can break */
+#define SUPERLINESIZE    100000/*used to read many many loci-sites and indiv numbers*/ 
 #define STRSIZE              255 /* setting this smaller can break */
 #define DEFAULT_NMLENGTH      10 /* length of individual names */
 #define DEFAULT_ALLELENMLENGTH 6 /* length of allele names */
@@ -238,13 +238,15 @@ typedef unsigned char boolean;
 /* don't change below here ------------------------------------
    some other constants */
 /* numerical borders and epsilons*/
+#ifndef HUGE
+#define HUGE 1e200
+#endif 
 #define SMALL_VALUE       10e-21
 #define EPSILON         0.000001 /* a small number */
 #define EPSILON4        0.000099 /* another small number */
 #define SMALLEPSILON       1e-15 /* a smaller number */
 #define BIGEPSILON         0.001 /* a not so small number */
 #define LONGCHAINEPSILON  10e100 /* an unreasonable big number,
-
 so that the given number of
 long chains is used */
 #define GELMAN_MYSTIC_VALUE 1.2
@@ -260,6 +262,8 @@ long chains is used */
 #endif
 #endif
 /* some math constants */
+#define HALF 0.5
+#define QUARTER 0.25
 #define LOGDBL_EPSILON -36.04365338911715608 /*N[Log[DBL_EPSILON] ,30] */
 #define LOG1 0.
 #define LOG2 0.693147180559945309417232121458 /*N[Log[2] ,30] */
@@ -407,6 +411,11 @@ long chains is used */
 #define MANYCATEGS             2
 #define ONECATEG               1
 
+#ifndef LAMARC_MAC_INTERFACE
+#define eventloop() /* eventloop would go here */
+#endif
+
+
 #ifdef MEMDEBUG
 #include <memdebug.h>
 #endif
