@@ -10,7 +10,7 @@ This software is distributed free of charge for non-commercial use
 and is copyrighted. Of course, we do not guarantee that the software
 works and are not responsible for any damage you may cause or have.
  
-$Id: heating.c,v 1.13 2002/11/09 20:06:12 beerli Exp $
+$Id: heating.c,v 1.17 2003/11/20 19:49:04 beerli Exp $
  
 */
 #include "migration.h"
@@ -181,14 +181,17 @@ thread_tree_update (void *world)
     {
 #ifdef BAYESUPDATE
         if(thisworld->options->bayes_infer)
+        {
             thisworld->bayesaccept = bayes_update (thisworld);
-#endif
-
-        thisworld->accept = tree_update (thisworld, thisworld->G);
-        //      printf("%li> %s \n",i,thisworld->name);
+            thisworld->bayes->accept[world->numpop2] += thisworld->bayesaccept;   
+        }
+        else
+        {
+            thisworld->accept += tree_update (thisworld, thisworld->G);
+        }
+#endif /*not compiled for Bayesian choice*/
+        thisworld->accept += tree_update (thisworld, thisworld->G);
     }
-    //  return NULL;
-    //  pthread_exit(NULL);
 }
 
 int
@@ -302,20 +305,20 @@ void adjust_temperatures(world_fmt ** universe, long hchains, long step, long st
         {
             universe[0]->averageheat= 1.0;
             delta = calloc(hchains,sizeof(double));
-            // FPRINTF(stdout,"\n%f %li\n",1./universe[0]->heat,universe[0]->treeswapcount);
+	    // FPRINTF(stdout,"\n%f %li\n",1./universe[0]->heat,universe[0]->treeswapcount);
             for(i=1; i< hchains; i++)
             {
                 universe[i]->averageheat += (1./(universe[i]->heat * corrsum ));
-                //  FPRINTF(stdout,"%f %li\n",1./universe[i]->heat,universe[i]->treeswapcount);
+		//FPRINTF(stdout,"%f %li\n",1./universe[i]->heat,universe[i]->treeswapcount);
                 delta[i-1] = 1./universe[i]->heat - 1./universe[i-1]->heat;
             }
             for(i=1; i< hchains; i++)
             {
-                if(universe[i-1]->treeswapcount == HEATSWAPLOW)
+                if(universe[i-1]->treeswapcount <= HEATSWAPLOW)
                     delta[i-1] *= smaller;
                 else
                 {
-                    if(universe[i-1]->treeswapcount > HEATSWAPHIGH)
+                    if(universe[i-1]->treeswapcount >= HEATSWAPHIGH)
                         delta[i-1] *= bigger;
                 }
             }
