@@ -7,7 +7,7 @@
  
  moved out from world.c                                                                                                               
  Peter Beerli 2000, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
  Copyright 2001 Peter Beerli and Joseph Felsenstein
  
@@ -15,7 +15,7 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: lrt.c,v 1.24 2002/12/22 04:50:44 beerli Exp $
+$Id: lrt.c,v 1.26 2003/11/04 16:12:08 beerli Exp $
  
 -------------------------------------------------------*/
 #define SICK_VALUE    -1
@@ -711,8 +711,8 @@ set_test_param (double *param, lr_data_fmt *lrtdata, world_fmt * world, long lrl
     long pop1, pop2;
     
     paramtype = (char *) calloc (1, sizeof (char) * elem);
-    ss = (char *) calloc (LINESIZE, sizeof (char));
-    custm = (char **) calloc (LINESIZE, sizeof (char *));
+    ss = (char *) calloc (LONGLINESIZE, sizeof (char));
+    custm = (char **) calloc (LONGLINESIZE, sizeof (char *));
 
     strcpy (ss, lrtdata->value1);
 
@@ -882,12 +882,12 @@ return df;
 
 // in is the string from the l-ratio option, custom is a database array that
 // gets allocated while its filled
-// maximal event numbers is LINESIZE [search for use of simplify_lrtvalues()]
+// maximal event numbers is LONGLINESIZE [search for use of simplify_lrtvalues()]
 long simplify_lrtvalues(char * in, char*** out)
 {
     long elements=0;
     long count = 0;
-    (*out)[0] = calloc(LINESIZE,sizeof(char));
+    (*out)[0] = calloc(LONGLINESIZE,sizeof(char));
     while(*in!='\0')
       {
         switch(*in)
@@ -901,7 +901,7 @@ long simplify_lrtvalues(char * in, char*** out)
             case ';':
                 count=0;
                 elements++;
-                (*out)[elements] = calloc(LINESIZE,sizeof(char));
+                (*out)[elements] = calloc(LONGLINESIZE,sizeof(char));
                 break;
             default:
                 (*out)[elements][count++] = *in;
@@ -929,9 +929,9 @@ set_test_param (double *param, lr_data_fmt *lrtdata, world_fmt * world, long lrl
                    (world->options->replicatenum == 0 ?
                     world->options->lchains : world->options->replicatenum);
     *zeros = 0;
-    ss = (char *) calloc (1, sizeof (char) * LINESIZE);
-    custm = (char *) calloc (1, sizeof (char) * LINESIZE);
-    tmp = (char *) calloc (1, sizeof (char) * LINESIZE);
+    ss = (char *) calloc (1, sizeof (char) * LOGLINESIZE);
+    custm = (char *) calloc (1, sizeof (char) * LONGLINESIZE);
+    tmp = (char *) calloc (1, sizeof (char) * LONGLINESIZE);
     paramtype = (char *) calloc (1, sizeof (char) * elem);
 
     *maxnum = 0;
