@@ -13,7 +13,7 @@ and of course the documentation at:
         http://evolution.genetics.washington.edu/lamarc/migrate.html
  
  Peter Beerli, started 1997, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
  Copyright 2001 Peter Beerli and Joseph Felsenstein
  
@@ -21,7 +21,7 @@ and of course the documentation at:
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: main.c,v 1.95 2003/06/10 15:55:19 beerli Exp $
+$Id: main.c,v 1.101 2003/11/20 19:49:04 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "definitions.h"
@@ -145,6 +145,12 @@ run_loci(world_fmt ** universe, int usize, option_fmt * options,
          data_fmt * data, tpool_t * heating_pool, long maxreplicate,
          long *treefilepos, long *Gmax);
 
+void run_one_update(world_fmt *world);
+
+void run_updates(world_fmt ** universe,
+                 int usize, option_fmt * options,tpool_t * heating_pool,long inc,
+                 long increment,long step,long steps);
+
 void
 heated_swap(world_fmt ** universe, worldoption_fmt * options);
 
@@ -179,11 +185,6 @@ int
 setup_locus(long locus, world_fmt * world, option_fmt * options,
             data_fmt * data);
 
-void
-condense_time(world_fmt * world, long *step, long *j,
-              double *accepted, long *G, long *steps,
-              long oldsteps, long rep);
-
 long            set_repkind(option_fmt * options);
 
 void            heating_prepare2(world_fmt ** universe, int usize);
@@ -204,6 +205,7 @@ void change_longsum_times(world_fmt *world);
 
 extern void unset_penalizer_function(boolean inprofiles);
 
+
 /* Functions ++++++++++++++++++++++++++++++++++++++++++++++++ */
 /*--------------------------------------------
 main program
@@ -967,7 +969,7 @@ profile_tables(option_fmt * options, world_fmt * world, long *gmaxptr)
     if (options->profile != NONE)
     {
         world->buffer =
-            (char *) realloc(world->buffer, LINESIZE * 100 * sizeof(char));
+            (char *) realloc(world->buffer, SUPERLINESIZE * sizeof(char));
         if (options->printprofsummary)
             allocate_profile_percentiles(world);
 #ifdef HAVE_STRFTIME
@@ -1194,11 +1196,10 @@ heating_prepare2(world_fmt ** universe, int usize)
     {
         clone_polish(EARTH, universe[chain]);
 #ifdef BAYESUPDATE
-
         if (universe[chain]->options->bayes_infer)
             universe[chain]->bayesaccept = bayes_update(universe[chain]);
+	if(universe[chain]->bayesaccept == -1) //either do tree updates or parameter updates
 #endif
-
         (void) tree_update(universe[chain], 0);
     }
 }
@@ -1250,7 +1251,35 @@ run_locus(world_fmt ** universe, int usize, option_fmt * options,
     }
 }
 
+//============================================================
+// updates the tree and records acceptance
+// when in bayesian mode change between changing the tree and the parameters
+void
+run_one_update(world_fmt *world)
+{
+#ifdef BAYESUPDATE
+    long count=0;
+    if (world->options->bayes_infer)
+    {
+        world->bayesaccept = bayes_update(world);
+        if(world->bayesaccept == -1) //either do tree updates or parameter updates
+        {
+            world->accept += (count = tree_update(world, world->G));
+            world->bayes->accept[world->numpop2] += count;       //  permanent recorder for the tree acceptance, for some obscure reason the world->accept gets lost, most likely every cycle;
+        }
+    }
+    else
+    {
+        world->accept +=  tree_update(world, world->G);
+    }
+#else
+    world->accept +=  tree_update(world, world->G);
+#endif
+}
 
+//============================================================
+// controls updates and temperatures (threaded or unthreaded)
+// updates the tree and/or parameters
 void run_updates(world_fmt ** universe,
                 int usize,
                 option_fmt * options,
@@ -1269,12 +1298,7 @@ void run_updates(world_fmt ** universe,
 #else  /*heating but not using threads*/
         for (ii = 0; ii < options->heated_chains; ii++)
         {
-#ifdef BAYESUPDATE
-            if (universe[ii]->options->bayes_infer)
-                universe[ii]->bayesaccept = bayes_update(universe[ii]);
-#endif
-            universe[ii]->accept +=
-                tree_update(universe[ii], universe[ii]->G);
+            run_one_update(universe[ii]);
         }
 #endif /* end of not-using threads*/
         heated_swap(universe, EARTH->options);
@@ -1283,12 +1307,7 @@ void run_updates(world_fmt ** universe,
     }
     else /* no heating*/
       {
-#ifdef BAYESUPDATE
-        if (EARTH->options->bayes_infer)
-            EARTH->bayesaccept = bayes_update(EARTH);
-#endif
-        EARTH->accept +=
-            tree_update(EARTH, EARTH->G);        
+        run_one_update(EARTH);
       }
 #ifdef UEP
     if (options->uep && EARTH->in_last_chain)
