@@ -9,7 +9,7 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
@@ -17,7 +17,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: mcmc2.c,v 1.21 2002/08/12 21:13:54 beerli Exp $
+$Id: mcmc2.c,v 1.23 2003/11/04 16:12:09 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -513,7 +513,7 @@ target_stancoa (proposal_fmt * proposal)
 {
     node *obb, *nn, *oldnn, *d1, *d2, *proposalack, *upper = NULL; /* o R */
     node **double_line;
-    double_line = (node **) calloc (2, sizeof (node *));
+        double_line = (node **) calloc (2, sizeof (node *));
     if (proposal->ocousin != NULL)
     {
         obb = showtop (crawlback (proposal->oback));
@@ -622,7 +622,7 @@ target_stancoa (proposal_fmt * proposal)
             }
         }
     }
-    free (double_line);
+  free (double_line);
 }
 
 void
@@ -941,7 +941,11 @@ localevaluate (node * mother)
 void
 copy_x (proposal_fmt * proposal, xarray_fmt xx1, xarray_fmt xx2)
 {
+
+    const size_t sitelikesize = sizeof (sitelike);
+    
     long i, j;
+
     switch (proposal->datatype)
     {
     case 'a':
@@ -959,7 +963,7 @@ copy_x (proposal_fmt * proposal, xarray_fmt xx1, xarray_fmt xx2)
         {
             for (j = 0; j < proposal->world->options->rcategs; j++)
             {
-                memcpy (xx1.s[i][j], xx2.s[i][j], sizeof (sitelike));
+                memcpy (xx1.s[i][j], xx2.s[i][j], sitelikesize);
             }
         }
         break;
