@@ -7,7 +7,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
 
     presents the menu and its submenus.
     Peter Beerli 1996, Seattle
-    beerli@genetics.washington.edu
+    beerli@csit.fsu.edu
 
     Copyright 2001 Peter Beerli and Joseph Felsenstein
 
@@ -15,7 +15,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
     and is copyrighted. Of course, we do not guarantee that the software
     works and are not responsible for any damage you may cause or have.
 
-$Id: menu.c,v 1.63 2003/07/09 16:03:02 beerli Exp $
+$Id: menu.c,v 1.65 2003/11/04 16:12:09 beerli Exp $
 
 -------------------------------------------------------*/
 #include "migration.h"
@@ -2036,11 +2036,11 @@ check_lrt_allocation (lratio_fmt * lratio)
         {
             lratio->data[i].elem = 0;
             lratio->data[i].value1 =
-                (char *) calloc (1, sizeof (char) * LINESIZE);
+                (char *) calloc (1, sizeof (char) * LONGLINESIZE);
             lratio->data[i].value2 =
-                (char *) calloc (1, sizeof (char) * LINESIZE);
+                (char *) calloc (1, sizeof (char) * LONGLINESIZE);
             lratio->data[i].connect =
-                (char *) calloc (1, sizeof (char) * LINESIZE);
+                (char *) calloc (1, sizeof (char) * LONGLINESIZE);
 
         }
     }
@@ -2053,10 +2053,10 @@ menuread_lrt_paramvalue (char *value, long *counter, long numpop2)
     long pointer = 0;
     long z = 0;
     char *temp;
-    char input[LINESIZE];
+    char input[LONGLINESIZE];
     while (z < numpop2)
     {
-        FGETS (input, LINESIZE, stdin);
+        FGETS (input, LONGLINESIZE, stdin);
         temp = strtok (input, ", \n\t");
         if (temp != NULL)
         {
