@@ -2,7 +2,7 @@
   mig-histogram code
  
   Peter Beerli
-  beerli@gs.washington.edu
+  beerli@csit.fsu.edu
  
     Copyright 2002 Peter Beerli
  
@@ -10,7 +10,7 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-  $Id: mig-histogram.c,v 1.5 2002/08/12 21:13:54 beerli Exp $
+  $Id: mig-histogram.c,v 1.6 2003/11/04 16:12:09 beerli Exp $
  
  */
 
