@@ -1,6 +1,6 @@
 /* MPI parts for migrate
    started November 2000, Seattle
-   Peter Beerli beerli@genetics.washington.edu
+   Peter Beerli beerli@csit.fsu.edu
  
    
 Copyright 2001 Peter Beerli and Joseph Felsenstein
@@ -10,7 +10,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: migrate_mpi.c,v 1.30 2003/06/10 23:21:56 beerli Exp $
+$Id: migrate_mpi.c,v 1.32 2003/11/04 16:12:09 beerli Exp $
 */
 #ifdef MPI
 #include "definitions.h"
@@ -740,8 +740,8 @@ pack_databuffer (char **buffer, data_fmt * data, option_fmt * options)
     long sumtips, i;
 #endif
 
-    char fp[LINESIZE];
-    bufsize += LINESIZE;
+    char fp[LONGLINESIZE];
+    bufsize += LONGLINESIZE;
     *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
     bufsize += 1 + sprintf (fp, "%c %li %li %li\n", options->datatype, (long) data->hasghost,
                             data->numpop, data->loci);
@@ -854,7 +854,7 @@ void
 pack_allele_data (char **buffer, long *bufsize, data_fmt * data, long pop,
                   long ind)
 {
-    char fp[LINESIZE];
+    char fp[LONGLINESIZE];
     long locus;
     for (locus = 0; locus < data->loci; locus++)
     {
@@ -897,28 +897,28 @@ unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options)
     char *buf = buffer;
     char *input;
     long hasghost;
-    input = (char *) calloc (LINESIZE, sizeof (char));
-    sgets (input, LINESIZE, &buf);
+    input = (char *) calloc (LONGLINESIZE, sizeof (char));
+    sgets (input, LONGLINESIZE, &buf);
     sscanf (input, "%c%li%li%li", &options->datatype, &hasghost, &data->numpop,
             &data->loci);
     data->hasghost = (boolean) hasghost;
     init_data_structure1 (&data, options);
     for (locus = 0; locus < data->loci; locus++)
     {
-        sgets (input, LINESIZE, &buf);
+        sgets (input, LONGLINESIZE, &buf);
         sscanf (input, "%li", &data->seq->sites[locus]);
     }
-    sgets (input, LINESIZE, &buf);
+    sgets (input, LONGLINESIZE, &buf);
     sscanf (input, "%li%lf", &data->seq->addon, &data->seq->fracchange);
     // population data
     for (pop = 0; pop < data->numpop; pop++)
     {
-        sgets (input, LINESIZE, &buf);
+        sgets (input, LONGLINESIZE, &buf);
         sscanf (input, "%s", data->popnames[pop]);
         biggest=0;
         for(locus=0; locus<data->loci; locus++)
         {
-            sgets (input, LINESIZE, &buf);
+            sgets (input, LONGLINESIZE, &buf);
             sscanf (input, "%li %li", &data->numind[pop][locus],&data->numalleles[pop][locus]);
             if(biggest<data->numind[pop][locus])
                 biggest = data->numind[pop][locus];
@@ -928,11 +928,11 @@ unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options)
         {
             for (ind = 0; ind < biggest; ind++)
             {
-                sgets (input, LINESIZE, &buf);
+                sgets (input, LONGLINESIZE, &buf);
                 sscanf (input, "%s", data->indnames[pop][ind]);
                 for (locus = 0; locus < data->loci; locus++)
                 {
-                    sgets (input, LINESIZE, &buf);
+                    sgets (input, LONGLINESIZE, &buf);
                     sscanf (input, "%s %s", data->yy[pop][ind][locus][0],
                             data->yy[pop][ind][locus][1]);
                 }
@@ -944,7 +944,7 @@ unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options)
             {
                 for (ind = 0; ind < data->numind[pop][locus]; ind++)
                 {
-                    sgets (input, LINESIZE, &buf);
+                    sgets (input, LONGLINESIZE, &buf);
                     sscanf (input, "%s", data->indnames[pop][ind]);
                     input =(char *) realloc (input, sizeof (char) * (100 + data->seq->sites[locus]));
                     sgets (input, 100 + data->seq->sites[locus], &buf);
@@ -967,7 +967,7 @@ unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options)
     {
         for (pop = 0; pop < data->numpop * data->numpop; pop++)
         {
-            sgets (input, LINESIZE, &buf);
+            sgets (input, LONGLINESIZE, &buf);
             sscanf (input, "%lf%lf", &data->geo[pop], &data->lgeo[pop]);
         }
     }
@@ -975,7 +975,7 @@ unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options)
 #ifdef UEP
     if (options->uep)
     {
-        sgets (input, LINESIZE, &buf);
+        sgets (input, LONGLINESIZE, &buf);
         sscanf (input, "%li%li", &sumtips, &data->uepsites);
         data->uep =
             (int **) calloc (number_genomes (options->datatype) * sumtips,
@@ -987,7 +987,7 @@ unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options)
                 data->uep[i] = (int *) calloc (data->uepsites, sizeof (int));
                 for (i = 0; i < data->uepsites; i++)
                 {
-                    sgets (input, LINESIZE, &buf);
+                    sgets (input, LONGLINESIZE, &buf);
                     sscanf (input, "%i", &data->uep[pop][i]);
                 }
             }
@@ -1001,7 +1001,7 @@ unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options)
                     (int *) calloc (data->uepsites, sizeof (int));
                 for (i = 0; i < data->uepsites; i++)
                 {
-                    sgets (input, LINESIZE, &buf);
+                    sgets (input, LONGLINESIZE, &buf);
                     sscanf (input, "%i%i", &data->uep[pop][i],
                             &data->uep[pop + sumtips][i]);
                 }
@@ -1045,16 +1045,16 @@ unpack_result_buffer (char *buffer, world_fmt * world,
     double ***apg0 = world->apg0;
     char *input;
     char *buf = buffer;
-    input = (char*) calloc(LINESIZE,sizeof(char));
+    input = (char*) calloc(LONGLINESIZE,sizeof(char));
     if (maxrep>1)
         addon=1;
     for (rep = 0; rep < maxrep + addon; rep++)
     {
-        sgets (input, LINESIZE, &buf);
+        sgets (input, LONGLINESIZE, &buf);
         atl[rep][locus].param_like = atof (input);
         for (pop = 0; pop < 4 * numpop * numpop; pop++)
         {
-            sgets (input, LINESIZE, &buf);
+            sgets (input, LONGLINESIZE, &buf);
             atl[rep][locus].parameters[pop] = atof (input);
         }
     }
@@ -1063,7 +1063,7 @@ unpack_result_buffer (char *buffer, world_fmt * world,
     {
         for (pop = 0; pop < world->options->lsteps; pop++)
         {
-            sgets (input, LINESIZE, &buf);
+            sgets (input, LONGLINESIZE, &buf);
             apg0[rep][locus][pop] = atof (input);
         }
     }
@@ -1080,7 +1080,7 @@ pack_result_buffer (char **buffer, world_fmt * world,
     timearchive_fmt **atl = world->atl;
     double ***apg0 = world->apg0;
     long bufsize = 1;  //maxrep * (1 + 4*numpop*numpop + world->options->lsteps) * 42 ;
-    input = (char*) calloc(LINESIZE,sizeof(char));
+    input = (char*) calloc(LONGLINESIZE,sizeof(char));
     (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
     memset (*buffer, 0, sizeof (char) * bufsize);
     strcpy (input, "");
@@ -1122,8 +1122,8 @@ unpack_mighist_buffer (char *buffer, world_fmt * world,
     char *input;
     char *buf = buffer;
     aa = &world->mighistloci[locus];
-    input = (char*) calloc(LINESIZE,sizeof(char));
-    sgets (input, LINESIZE, &buf);
+    input = (char*) calloc(LONGLINESIZE,sizeof(char));
+    sgets (input, LONGLINESIZE, &buf);
     sscanf (input, "%li", &aa->mighistnum);
     if(aa->allocsize <= aa->mighistnum)
     {
@@ -1140,7 +1140,7 @@ unpack_mighist_buffer (char *buffer, world_fmt * world,
     }
     for (j = 0; j < aa->mighistnum; j++)
     {
-        sgets (input, LINESIZE, &buf);
+        sgets (input, LONGLINESIZE, &buf);
         sscanf (input, "%li %li %li", &aa->mighist[j].copies,
                 &aa->mighist[j].weight, &aa->mighist[j].migeventsize);
         //printf("%i> events: alloc=%li size=%li\n", myID, aa->mighist[j].allocsize , aa->mighist[j].migeventsize);
@@ -1150,7 +1150,7 @@ unpack_mighist_buffer (char *buffer, world_fmt * world,
                                    aa->mighist[j].allocsize);
         for (i = 0; i < aa->mighist[j].migeventsize; i++)
         {
-            sgets (input, LINESIZE, &buf);
+            sgets (input, LONGLINESIZE, &buf);
             sscanf (input, "%lf %lf %lf",
                     &aa->mighist[j].migevents[i][0],
                     &aa->mighist[j].migevents[i][1],
@@ -1170,7 +1170,7 @@ pack_mighist_buffer (char **buffer, world_fmt * world,
     char *input;
     long bufsize = 1;
     aa = &world->mighistloci[locus];
-    input = (char*) calloc(LINESIZE,sizeof(char));
+    input = (char*) calloc(LONGLINESIZE,sizeof(char));
     for (j = 0; j < aa->mighistnum; j++)
         bufsize += 100 + aa->mighist[j].migeventsize * 100;
     (*buffer) = (char *) realloc ((*buffer), sizeof (char) * bufsize);
@@ -1207,10 +1207,10 @@ unpack_sumfile_buffer (char *buffer, world_fmt * world,
     char *input;
     timearchive_fmt **ta = world->atl;
     char *buf = buffer;
-    input = (char*) calloc(LINESIZE*world->numpop2,sizeof(char));
+    input = (char*) calloc(LONGLINESIZE*world->numpop2,sizeof(char));
     for (r = 0; r < maxrep; r++)
     {
-        sgets (input, LINESIZE, &buf);
+        sgets (input, LONGLINESIZE, &buf);
         sscanf (input, "%li %li %li %lg", &ta[r][l].T, &ta[r][l].numpop,
                 &ta[r][l].sumtips, &ta[r][locus].param_like);
         world->chainlikes[l][r] = ta[r][l].param_like;
@@ -1218,21 +1218,21 @@ unpack_sumfile_buffer (char *buffer, world_fmt * world,
         increase_timearchive (world, l, ta[r][l].T, world->numpop, r);
         for (i = 0; i < ta[r][l].T; i++)
         {
-            sgets (input, LINESIZE, &buf);
+            sgets (input, LONGLINESIZE, &buf);
             sscanf (input, "%li %lg", &ta[r][l].tl[i].copies, &ta[r][l].tl[i].lcopies);
             for (j = 0; j < 3 * numpop + numpop * (numpop - 1); j++)
             {
-                sgets (input, LINESIZE, &buf);
+                sgets (input, LONGLINESIZE, &buf);
                 sscanf (input, "%lg", &ta[r][l].tl[i].data[j]);
             }
         }
         for (i = 0; i < world->numpop2; i++)
         {
-            sgets (input, LINESIZE, &buf);
+            sgets (input, LONGLINESIZE, &buf);
             sscanf (input, "%lg %lg", &ta[r][l].param[i], &ta[r][l].param0[i]);
         }
         log_param0 (ta[r][l].param0, ta[r][l].lparam0, world->numpop2);
-        sgets (input, LINESIZE, &buf);
+        sgets (input, LONGLINESIZE, &buf);
         sscanf (input, "%li %lg", &ta[r][l].trials, &ta[r][l].normd);
     }
     free(input);
@@ -1262,7 +1262,7 @@ pack_sumfile_buffer (char **buffer, world_fmt * world,
     tempbuffer2 = (char *) calloc(101* (22+ 3 * numpop + numpop * (numpop - 1) * 22 + 50 * numpop * numpop + 50),sizeof(char));
     (*buffer)[0] = '\0';
     //memset (*buffer, 0, sizeof (char));
-    input = (char*) calloc(LINESIZE*world->numpop2,sizeof(char));
+    input = (char*) calloc(LONGLINESIZE*world->numpop2,sizeof(char));
     for (r = 0; r < maxrep; r++)
     {
         sprintf (input, "%li %li %li %g \n", ta[r][l].T,
@@ -1700,8 +1700,8 @@ long
 pack_quantile (char **buffer, quantile_fmt quant, long n)
 {
     long i;
-    char fp[LINESIZE];
-    long bufsize = LINESIZE;
+    char fp[LONGLINESIZE];
+    long bufsize = LONGLINESIZE;
     *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
     sprintf (*buffer, "QUANTILEBUFFER:\n %s\n", quant.name);
     for (i = 0; i < n; i++)
@@ -1719,13 +1719,13 @@ unpack_quantile (char *buffer, quantile_fmt quant, long n)
     long i;
     char *input;
     char *buf = buffer;
-    input = (char*) calloc(LINESIZE,sizeof(char));
-    sgets (input, LINESIZE, &buf);
-    sgets (input, LINESIZE, &buf);
+    input = (char*) calloc(LONGLINESIZE,sizeof(char));
+    sgets (input, LONGLINESIZE, &buf);
+    sgets (input, LONGLINESIZE, &buf);
     strcpy (quant.name, input);
     for (i = 0; i < n; i++)
     {
-        sgets (input, LINESIZE, &buf);
+        sgets (input, LONGLINESIZE, &buf);
         quant.param[i] = atof (input);
     }
     free(input);
@@ -1750,7 +1750,7 @@ void distribute_locidata(world_fmt *world)
 void pack_loci_data(world_fmt *world, char **buffer)
 {
   long replicates = world->options->repl
-  *buffer = realloc(*buffer,LINESIZE);
+  *buffer = realloc(*buffer,LONGLINESIZE);
   hits = sscanf (input, "%li %li %li %li %li", &world->loci, &world->numpop, &world->numpop2, &tmp, &replicates);  
 }
 */
