@@ -14,11 +14,11 @@
  and finally helps to destroy itself.
                                                                                                                
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: options.h,v 1.21 2003/03/13 20:15:34 beerli Exp $
+$Id: options.h,v 1.22 2003/11/04 16:12:09 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
