@@ -6,7 +6,7 @@
  P R O F I L E    L I K E L I H O O D    R O U T I N E S 
  
  Peter Beerli 1997, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
@@ -15,7 +15,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: profile.c,v 1.66 2003/07/07 21:14:13 beerli Exp $
+$Id: profile.c,v 1.68 2003/11/04 16:12:09 beerli Exp $
  
 -------------------------------------------------------*/
 
@@ -262,7 +262,7 @@ print_profile_table (char method, long which, char *var, double likes[],
         world->options->gamma ? world->numpop * world->numpop +
         1 : world->numpop * world->numpop;
 
-    char fp[LINESIZE * 10]; //large local string buffer
+    char fp[LONGLINESIZE]; //large local string buffer
     char **buffer = &world->buffer; // buffer for printing whole table
     long bufsize = 1;
     char *temp, *var2, temp2[LINESIZE], likestr[LINESIZE], *paramstr;
