@@ -9,11 +9,11 @@
  R E P O R T E R   R O U T I N E S 
                                                                                                                
  Peter Beerli 1999, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: reporter.h,v 1.6 2002/06/20 06:25:38 beerli Exp $
+$Id: reporter.h,v 1.7 2003/11/04 16:12:09 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
