@@ -11,11 +11,11 @@
  from the AMS library
  
  Peter Beerli 1999, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: spline.h,v 1.8 2002/06/20 06:25:38 beerli Exp $
+$Id: spline.h,v 1.9 2003/11/04 16:12:10 beerli Exp $
 -------------------------------------------------------*/
 
 extern int dbvssc_ (double *x, double *y, long *np, long *n, long *k,
