@@ -10,7 +10,7 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
@@ -19,7 +19,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c,v 1.61 2003/03/13 20:15:35 beerli Exp $
+$Id: tools.c,v 1.65 2003/11/04 16:12:10 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "sighandler.h"
@@ -305,7 +305,7 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
                 openfile (&world->mathfile, options->mathfilename, "w+", appl,
                           NULL);
 #ifdef MPI
-				setup_filehandle_db((void *) world->mathfile, world, options, data);
+                setup_filehandle_db((void *) world->mathfile, world, options, data);
 #endif
                 break;
             default:  /*e.g. 0 this create just the plots in outfile */
@@ -516,16 +516,51 @@ print_llike (double llike, char *strllike)
         sprintf (strllike, "%-10.5f", llike);
 }
 
-
+//========================================
+// remove traling whitespace from a *string
 void remove_trailing_blanks(char **filename)
 {
-  int pos;;
+  int pos;
   pos = strlen(*filename);
   while (isspace( (*filename)[pos]) && pos>0)
     pos--;
   (*filename)[pos] = '\0';   
 }
 
+//========================================
+// read a single word from a file
+// words are delimited by withespace 
+void read_word(FILE *infile, char *word)
+{
+    int ch;
+    long count = 0;
+    ch = getc(infile);
+    while (isspace (ch))
+        ch = getc(infile);
+    while(strchr(" \t\n\r", ch)==NULL)
+    {
+        word[count++] = ch;
+        ch = getc(infile);
+    }
+    word[count]='\0';
+    ungetc(ch,infile);
+}
+
+//========================================
+// prepends a string to a file
+// a blank will be inserted between the string and the
+// text in the file
+void unread_word(FILE *infile, char *word)
+{
+    long count = strlen(word);
+    ungetc(' ', infile);
+    while(count > 0)
+    {
+        count--;
+        ungetc(word[count], infile);
+    }
+}
+
 void
 openfile (FILE ** fp, char *filename, char *mode, const char *application,
           char *perm)
@@ -874,7 +909,7 @@ node *crawl(node * theNode)
 }
 */
 
-
+ 
 node *
 showtop (node * theNode)
 {
@@ -2494,7 +2529,8 @@ print_line (FILE * outfile, char c, long nn, long flag)
 
 
 void
-sprint_line (char *buffer, char c, long nn, long flag)
+sprint_line
+(char *buffer, char c, long nn, long flag)
 {
     char ch[2];
     long i, start = 0;
