@@ -9,11 +9,11 @@
  H E L P E R     R O U T I N E S 
  
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: tools.h,v 1.17 2001/07/25 19:27:24 beerli Exp $
+$Id: tools.h,v 1.26 2003/11/04 16:12:10 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -24,15 +24,15 @@ extern node *crawl (node * theNode);
 extern node *showtop (node * theNode);
 extern void adjust_time (node * theNode, double tyme);
 extern void insert_migr_node (world_fmt * world, node * up, node * down,
-                                migr_table_fmt * migr_table,
-                                long *migr_table_counter);
+                                  migr_table_fmt * migr_table,
+                                  long *migr_table_counter);
 extern void children (node * mother, node ** brother, node ** sister);
 /* math tools */
 extern double incompletegamma (double x, double alpha);
 extern double polygamma (long n, double z);
 extern void invert_matrix (double **a, long nsize);
 extern boolean nrcheck (double **m, double **tm, double *v, long nrows,
-                          double *r1, double *r2, boolean do_newton);
+                            double *r1, double *r2, boolean do_newton);
 extern double rannor (double mean, double sd);
 extern double find_chi (long df, double prob);
 extern double probchiboundary (double chi, long zeros, long all);
@@ -40,7 +40,7 @@ extern double chiboundary (long zeros, long nonzeros, double alpha);
 extern double probchi (long df, double chi);
 extern double chisquare (long df, double alpha);
 extern void gamma_rates (double *rate, double *probcat, long categs,
-                           char *input);
+                             char *input);
 #ifndef HAVE_LGAMMA
 extern double mylgamma (double z);
 #endif
@@ -60,18 +60,20 @@ extern void add_vector (double *result, double *v, long size);
 
 /*filemanipulation */
 extern void init_files (world_fmt * world, data_fmt * data,
-                          option_fmt * options);
+                            option_fmt * options);
 extern void exit_files (world_fmt * world, data_fmt * data,
-                          option_fmt * options);
+                            option_fmt * options);
 extern void openfile (FILE ** fp, char *filename, char *mode,
-                        const char *application, char *perm);
+                          const char *application, char *perm);
 extern long read_savesum (world_fmt * world, option_fmt * options,
-                            data_fmt * data);
+                              data_fmt * data);
 extern void write_savesum (world_fmt * world);
 
 /* string manipulation */
 extern void translate (char *text, char from, char to);
 extern long count_words (char *text);
+extern void read_word(FILE *infile, char *word);
+extern void unread_word(FILE *infile, char *word);
 /* time reporting */
 extern void get_time (char *nowstr, char ts[]);
 /* printing aid */
