@@ -9,11 +9,11 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: tree.h,v 1.19 2002/06/20 06:25:40 beerli Exp $
+$Id: tree.h,v 1.20 2003/11/04 16:12:10 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
