@@ -6,7 +6,7 @@
  Unique event polymorphism   R O U T I N E S
  
  Peter Beerli 2000, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2002 Peter Beerli and Joseph Felsenstein
  
@@ -14,7 +14,7 @@ Copyright 2002 Peter Beerli and Joseph Felsenstein
         and is copyrighted. Of course, we do not guarantee that the software
         works and are not responsible for any damage you may cause or have.
  
-$Id: uep.c,v 1.32 2002/10/04 23:11:36 beerli Exp $
+$Id: uep.c,v 1.33 2003/11/04 16:12:10 beerli Exp $
 */
 #ifdef UEP
 #include "migration.h"
