@@ -15,11 +15,11 @@
  and finally helps to destroy itself.
                                                                                                                
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: world.h,v 1.25 2002/11/09 20:06:14 beerli Exp $
+$Id: world.h,v 1.26 2003/11/04 16:12:10 beerli Exp $
  
 -------------------------------------------------------*/
 
